@@ -19,7 +19,7 @@ require PHPSECLIB_INC_DIR . '/Crypt/Random.php';
 
 if (!@function_exists('session_name')) {
     PMA_warnMissingExtension('session', true);
-} elseif (ini_get('session.auto_start') == true && session_name() != 'phpMyAdmin') {
+} elseif (ini_get('session.auto_start') !== '' && session_name() != 'phpMyAdmin') {
     // Do not delete the existing session, it might be used by other
     // applications; instead just close it.
     session_write_close();
@@ -103,6 +103,11 @@ if (! isset($_COOKIE[$session_name])) {
     session_start();
 }
 
+/**
+ * Disable setting of session cookies for further session_start() calls.
+ */
+@ini_set('session.use_cookies', 'true');
+
 /**
  * Token which is used for authenticating access queries.
  * (we use "space PMA_token space" to prevent overwriting)
@@ -129,4 +134,3 @@ function PMA_secureSession()
     }
     $_SESSION[' PMA_token '] = bin2hex(phpseclib\Crypt\Random::string(16));
 }
-?>
